@@ -141,14 +141,13 @@ class GpuNUFFTPythonOperator
         gpuNUFFT::Dimensions myDims = imgDims;
         if(grid_data)
             myDims = myDims * gpuNUFFTOp->getOsf();
-        int depth = myDims.depth;
         if(dimension==2)
             myDims.depth = 1;
         py::array_t<std::complex<DType>> out_result;
         if(has_sense_data == false)
-            out_result.resize({n_coils, depth, (int)myDims.height, (int)myDims.width});
+            out_result.resize({n_coils, (int)myDims.depth, (int)myDims.height, (int)myDims.width});
         else
-            out_result.resize({depth, (int)myDims.height, (int)myDims.width});
+            out_result.resize({(int)myDims.depth, (int)myDims.height, (int)myDims.width});
         py::buffer_info out = out_result.request();
         std::complex<DType> *t_data = (std::complex<DType> *) out.ptr;
         DType2 *new_data = reinterpret_cast<DType2(&)[0]>(*t_data);
@@ -171,10 +170,18 @@ class GpuNUFFTPythonOperator
     {
        gpuNUFFTOp->clean_memory();
     }
+    void set_smaps(py::array_t<std::complex<DType>> sense_maps)
+    {
+        free(sensArray.data);
+        sensArray = copyNumpyArray(sense_maps, imgDims.count() * n_coils);
+        sensArray.dim = imgDims;
+        sensArray.dim.channels = n_coils;
+        has_sense_data = true;
+        gpuNUFFTOp->setSens(sensArray);
+    }
     ~GpuNUFFTPythonOperator()
     {
-        if(has_sense_data == true)
-            free(sensArray.data);
+        delete gpuNUFFTOp;
     }
 };
 PYBIND11_MODULE(gpuNUFFT, m) {
@@ -182,6 +189,7 @@ PYBIND11_MODULE(gpuNUFFT, m) {
         .def(py::init<py::array_t<DType>, py::array_t<int>, int, py::array_t<std::complex<DType>>, py::array_t<float>, int, int, int, bool>())
         .def("op", &GpuNUFFTPythonOperator::op)
         .def("adj_op",  &GpuNUFFTPythonOperator::adj_op)
-        .def("clean_memory", &GpuNUFFTPythonOperator::clean_memory);
+        .def("clean_memory", &GpuNUFFTPythonOperator::clean_memory)
+        .def("set_smaps", &GpuNUFFTPythonOperator::set_smaps);
 }
 #endif  // GPUNUFFT_OPERATOR_MATLABFACTORY_H_INCLUDED
