@@ -1041,10 +1041,6 @@ void gpuNUFFT::GpuNUFFTOperator::performForwardGpuNUFFT(
       printf("error: at thread synchronization 8: %s\n",
              cudaGetErrorString(cudaGetLastError()));
     
-    // Also apply density compensation here
-    if (this->applyDensComp())
-      performDensityCompensation(data_d, density_comp_d, gi_host);
-
     // write result in correct order back into output array
     writeOrderedGPU(data_sorted_d, data_indices_d, data_d,
                     (int)this->kSpaceTraj.count(), n_coils_cc);
@@ -1075,7 +1071,6 @@ void gpuNUFFT::GpuNUFFTOperator::performForwardGpuNUFFT(
 //
 // parameters:
 //  * data         : output kspace data
-//  * data_count   : number of samples on trajectory
 //  * n_coils      : number of channels or coils
 //  * crds         : coordinates on trajectory, passed as SoA
 //  * imdata       : input image data
@@ -1254,10 +1249,6 @@ void gpuNUFFT::GpuNUFFTOperator::performForwardGpuNUFFT(
       printf("error: at thread synchronization 8: %s\n",
              cudaGetErrorString(cudaGetLastError()));
 
-    // Also apply density compensation here
-    if (this->applyDensComp())
-      performDensityCompensation(data_d, density_comp_d, gi_host);
-
     // write result in correct order back into output array
     writeOrderedGPU(data_sorted_d, data_indices_d, data_d,
                     (int)this->kSpaceTraj.count(), n_coils_cc);
@@ -1320,4 +1311,4 @@ float gpuNUFFT::GpuNUFFTOperator::stopTiming()
 void gpuNUFFT::GpuNUFFTOperator::clean_memory()
 {
     this->freeDeviceMemory();
-}
\ No newline at end of file
+}
